@@ -43,9 +43,10 @@ from time import mktime
 
 svc_logger = logger.get_SVCLogger(__name__)
 
-API_SERVER_LOGIN_URL = "https://seachat.seasalt.ai/api/v1/user/login"
-API_SERVER_TTS_SERVICE_URL = "https://seachat.seasalt.ai/api/v1/speech/text_to_speech"
-API_SERVER_STT_SERVICE_URL = "https://seachat.seasalt.ai/api/v1/speech/speech_to_text"
+API_SERVER_LOGIN_URL = "https://suite.seasalt.ai/api/v1/user/login"
+API_SERVER_TTS_SERVICE_URL = "https://suite.seasalt.ai/api/v1/speech/text_to_speech"
+API_SERVER_STT_SERVICE_URL = "https://suite.seasalt.ai/api/v1/speech/stt_server_url"
+API_SERVER_STT_SERVICE_URL_TOKEN = "https://suite.seasalt.ai/api/v1/speech/speech_to_text"
 
 SUPPORTED_AUDIO_FORMAT = {
     'riff-8khz-16bit-mono-pcm': {
@@ -75,6 +76,7 @@ class SpeechConfig():
         host: Optional[Text] = '',
         account_id: Text = '',
         password: Text = '',
+        apikey: Text = '',
         speech_recognition_language: Text = 'zh-TW',
         speech_recognition_punctuation: bool = False,
         speech_synthesis_language: Text = 'zh-TW',
@@ -87,6 +89,7 @@ class SpeechConfig():
         self.__host = host
         self.__account_id = account_id
         self.__password = password
+        self.__apikey = apikey
         self.__speech_recognition_language = speech_recognition_language
         self.__speech_recognition_punctuation = speech_recognition_punctuation
         self.__speech_synthesis_language = speech_synthesis_language
@@ -115,6 +118,11 @@ class SpeechConfig():
         """Return password"""
         return self.__password
 
+    @property
+    def apikey(self) -> Text:
+        """Return apikey"""
+        return self.__apikey
+
     @property
     def format_label(self) -> Text:
         """Return format label"""
@@ -232,19 +240,26 @@ class Recognizer(WebSocketClient):
         # load speech_config
         self.__speech_config = speech_config
         self.__account_id = speech_config.account_id
-        if speech_config.get_login_token() is False:
-            svc_logger.error(f"Failed to login API server for {self.__account_id}, please make sure account_id and password are right.")
-            return None
-        self.__login_token = speech_config.login_token
         self.__format_label = speech_config.format_label
         self.__speech_recognition_language = speech_config.speech_recognition_language
         self.__speech_recognition_punctuation = speech_config.speech_recognition_punctuation
         self.__recognizer_semaphore = threading.Semaphore(0)
 
-        # get an available stt server url and speech token
-        if self.get_server_url_token() is False:
-            svc_logger.error(f"Can't get an available stt server, please confirm language setting, then try again.")
-            return None
+        if not speech_config.apikey:
+            if speech_config.get_login_token() is False:
+                svc_logger.error(f"Failed to login API server for {self.__account_id}, please make sure account_id and password are right.")
+                return None
+            self.__login_token = speech_config.login_token
+
+            # get an available stt server url and speech token
+            if self.get_server_url_token() is False:
+                svc_logger.error(f"Can't get an available stt server and speech token, please confirm language setting, then try again.")
+                return None
+        else:
+            self.__token = speech_config.apikey
+            if self.get_server_url() is False:
+                svc_logger.error(f"Can't get an available stt server, please confirm language setting, then try again.")
+                return None
         self.__ws_uri = f"{self.__host}?token={self.__token}&punctuation={self.__speech_recognition_punctuation}"
 
         # load audio_config
@@ -281,7 +296,7 @@ class Recognizer(WebSocketClient):
     def get_server_url_token(self) -> bool:
         """get stt server url and speech token by login token"""
         headers = {'Content-Type': 'text/plain', 'token': self.__login_token}
-        response = requests.post(API_SERVER_STT_SERVICE_URL, headers=headers,
+        response = requests.post(API_SERVER_STT_SERVICE_URL_TOKEN, headers=headers,
                                  json={'language': self.__speech_recognition_language})
         if response.status_code == 200:
             response_json = response.json()
@@ -289,7 +304,20 @@ class Recognizer(WebSocketClient):
             self.__token = response_json['token']
             return True
         else:
-            svc_logger.error(f"Error while getting stt server and token: {response.status_code} for account_id: {self.__account_id}")
+            svc_logger.error(f"Error while getting stt server url and token: {response.status_code} for account_id: {self.__account_id}")
+            return False
+
+    def get_server_url(self) -> bool:
+        """get stt server url by apikey"""
+        headers = {'Content-Type': 'text/plain', 'speech_token': self.__token}
+        url = f"{API_SERVER_STT_SERVICE_URL}?language={self.__speech_recognition_language}"
+        response = requests.get(url, headers=headers)
+        if response.status_code == 200:
+            response_json = response.json()
+            self.__host = response_json['server_url']
+            return True
+        else:
+            svc_logger.error(f"Error while getting stt server url: {response.status_code} for account_id: {self.__account_id}")
             return False
 
     def recognize_once(self):
